/**
 * Retrieves all query parameters from the current URL as an object.
 * Each key and value in the query string is parsed and added to the result object.
 *
 * @returns {object} An object containing the URL's query parameters, deserialized if necessary.
 */
export declare function getQueryParams(): object;
/**
 * Updates the current URL with the provided object's properties as query parameters.
 * Serializes the object, flattens it if needed, and sets each key-value pair as a query parameter.
 *
 * @template T
 * @param {T} data - An object containing key-value pairs to set as query parameters.
 * @returns {void} Does not return a value.
 */
export declare function setQueryParams<T>(data: T): void;
/**
 * Retrieves a specific query parameter value from the current URL by matching a given property name.
 * Searches for a key that includes the provided property string, returning its associated value if found.
 *
 * @param {string} property - The property name to look for in the query parameters.
 * @returns {unknown} The value associated with the provided property in the URL, if it exists.
 */
export declare function getQueryParamsByKey(property: string): unknown;
/**
 * Sets or updates a single query parameter in the current URL with a given key-value pair.
 * Serializes the key-value pair if necessary and updates the URL without reloading the page.
 *
 * @param {string} key - The name of the query parameter to set or update.
 * @param {unknown} value - The value of the query parameter to set.
 * @returns {void} Does not return a value.
 */
export declare function setQueryParamsByKey(key: string, value: unknown): void;
/**
 * remove current queries from the path
 * @returns {void} Does not return a value.
 * */
export declare function removeQueryParams(): void;
